searchData={"items":[{"type":"module","title":"Opts","doc":"`Opts` is a utility module to increase ergonomics when working with\noptions in keyword lists given to your functions.","ref":"Opts.html"},{"type":"function","title":"Opts.apply/4","doc":"Apply a function to the acc and a value of a key in the opts.\nIf the key is not present, the acc is returned as-is.\n\nThis function is useful for conditionally building some\naccumlator based on optional values.\n\nA common use-case is to build an Ecto query based on options\nlike `offset`, `limit`, `offset`, `where`'s etc.\n\nThis is similar to `Enum.reduce/3` over the options with\nthe query as the accumulator, but with the ability to\ndetermine order and inject other actions in the middle of\nthe pipeline.","ref":"Opts.html#apply/4"},{"type":"function","title":"Examples - Opts.apply/4","doc":"iex> opts = [a: 1, c: 3]\n    iex> acc = 0\n    iex> acc\n    iex> |> Opts.apply(opts, :a, &+/2)\n    iex> |> Opts.apply(opts, :b, &+/2)\n    iex> # example of modification in the middle of the pipeline:\n    iex> |> Function.identity()\n    iex> |> Opts.apply(opts, :c, &+/2)\n    4","ref":"Opts.html#apply/4-examples"},{"type":"function","title":"Opts.defaults/2","doc":"Apply defaults to a `t:Keyword.t`.\nThis is identical to `Keyword.merge/2` but in reverse argument order\nsuch that the subject is the opts.","ref":"Opts.html#defaults/2"},{"type":"function","title":"Examples - Opts.defaults/2","doc":"iex> opts = [a: 1, c: 3]\n    iex> defaults = [a: 0, b: 2]\n    iex> Opts.defaults(opts, defaults)\n    [b: 2, a: 1, c: 3]","ref":"Opts.html#defaults/2-examples"},{"type":"function","title":"Opts.map/2","doc":"Map over a list of options.\n\nThis is identical to `Enum.map/2`, but will only work with list as the enumerable argument.","ref":"Opts.html#map/2"},{"type":"function","title":"Examples - Opts.map/2","doc":"iex> opts = [a: 1, c: 3, b: 2]\n    iex> Opts.map(opts, fn {k, v} -> {k, v * 2} end)\n    [a: 2, c: 6, b: 4]","ref":"Opts.html#map/2-examples"},{"type":"function","title":"Opts.reduce/3","doc":"Reduce a list of options into an accumulator.\n\nThis is identical to `Enum.reduce/3`,\nbut will only work with list as the enumerable argument.","ref":"Opts.html#reduce/3"},{"type":"function","title":"Examples - Opts.reduce/3","doc":"iex> opts = [a: 1, c: 3, b: 2]\n    iex> Opts.reduce(opts, 0, fn {_k, v}, acc -> acc + v end)\n    6","ref":"Opts.html#reduce/3-examples"},{"type":"function","title":"Opts.rereduce/3","doc":"Reduce into an accumulator, a `t:Keyword.t`.\n\nLike `Enum.reduce/3`, but the accumulator is given as the first argument.\nThe accumulator is the first argument, such that\nit can be used in a pipeline over some accumulator\nin a \"builder\" pattern, and can be applied in a pipeline\nagain and again, processing the same accumulator (e.g. building a query, etc.)","ref":"Opts.html#rereduce/3"},{"type":"function","title":"Examples - Opts.rereduce/3","doc":"iex> opts = [a: 1, c: 3, b: 2]\n    iex> Opts.rereduce(0, opts, fn {_k, v}, acc -> acc + v end)\n    6","ref":"Opts.html#rereduce/3-examples"},{"type":"function","title":"Opts.split/2","doc":"Split a `t:Keyword.t` like `Keyword.split/2`\n\nIn addition to the guarantees of `Keyword.split/2`,\nit also guarantees that the order of the keys of the keyword list\nin the first tuple element is the same as the order of the specified keys,\nand that the order of the keys of the keyword list in the second tuple element\nis maintained from the original keyword list.\n\nDuplicates are preserved.","ref":"Opts.html#split/2"},{"type":"function","title":"Examples - Opts.split/2","doc":"iex> Opts.split([a: 1, c: 3, b: 2], [:b, :c])\n    {[b: 2, c: 3], [a: 1]}\n\n    iex> Opts.split([a: 1, c: 3, b: 2], [:c, :b])\n    {[c: 3, b: 2], [a: 1]}\n\n    iex> Opts.split([a: 1, c: 3, b: 2], [:a])\n    {[a: 1], [c: 3, b: 2]}","ref":"Opts.html#split/2-examples"},{"type":"function","title":"Opts.take/2","doc":"Take the keys from the `t:Keyword.t` first argument.\nThe order of the keys in the resulting keyword list\nis the same as the order of the keys in the second argument.\n\nDuplicates are preserved.","ref":"Opts.html#take/2"},{"type":"function","title":"Examples - Opts.take/2","doc":"iex> Opts.take([a: 1, c: 3, b: 2], [:b, :c])\n    [b: 2, c: 3]\n\n    iex> Opts.take([a: 1, c: 3, b: 2], [:c, :b])\n    [c: 3, b: 2]","ref":"Opts.html#take/2-examples"},{"type":"function","title":"Opts.take!/2","doc":"Take the keys from the `t:Keyword.t` first argument.\n\nLike `Opts.take/2`, but raises if options exist that are\nnot present in the list of keys.","ref":"Opts.html#take!/2"},{"type":"function","title":"Examples - Opts.take!/2","doc":"iex> Opts.take!([a: 1, b: 2], [:a, :b])\n    [a: 1, b: 2]\n\n    iex> Opts.take!([a: 1, b: 2], [:a, :b, :c])\n    [a: 1, b: 2]\n\n    iex> Opts.take!([a: 1, b: 2], [:a])\n    ** (Opts.OptsError) Unknown keys: [:b]","ref":"Opts.html#take!/2-examples"},{"type":"exception","title":"Opts.OptsError","doc":"","ref":"Opts.OptsError.html"},{"type":"extras","title":"Opts","doc":"# Opts\n\nA tiny Elixir library for working with `Keyword.t()` lists\nin a \"builder\"-like pattern.\n\nUseful for Context modules where you build queries based on provided options.","ref":"readme.html"},{"type":"extras","title":"Installation - Opts","doc":"The package can be installed by adding `opts` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:opts, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,51,46,48]}}